summaryrefslogtreecommitdiffstats
path: root/net/base/cert_verify_result.h
diff options
context:
space:
mode:
authorpalmer@chromium.org <palmer@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-09-07 12:52:26 +0000
committerpalmer@chromium.org <palmer@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-09-07 12:52:26 +0000
commitede03219316ddd2b8e5fea48bd2f592f255036ac (patch)
tree531919046cd5d4d154c0ec75863ab91841f92053 /net/base/cert_verify_result.h
parent98822821eb6a0e5cd3d2017dc6003fc64af0e3cc (diff)
downloadchromium_src-ede03219316ddd2b8e5fea48bd2f592f255036ac.zip
chromium_src-ede03219316ddd2b8e5fea48bd2f592f255036ac.tar.gz
chromium_src-ede03219316ddd2b8e5fea48bd2f592f255036ac.tar.bz2
Implement SHA-256 fingerprint support
The HTTP-based Public Key Pinning Internet Draft (tools.ietf.org/html/draft-ietf-websec-key-pinning) requires this. Per wtc, give the *Fingeprint* types more meaningful *HashValue* names. Cleaning up lint along the way. BUG=117914 TEST=net_unittests, unit_tests TransportSecurityPersisterTest Review URL: https://chromiumcodereview.appspot.com/10826257 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@155365 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/base/cert_verify_result.h')
-rw-r--r--net/base/cert_verify_result.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/net/base/cert_verify_result.h b/net/base/cert_verify_result.h
index 06baad2..e98dcfe 100644
--- a/net/base/cert_verify_result.h
+++ b/net/base/cert_verify_result.h
@@ -45,10 +45,10 @@ class NET_EXPORT CertVerifyResult {
bool has_md5_ca;
bool has_md2_ca;
- // If the certificate was successfully verified then this contains the SHA1
- // fingerprints of the SubjectPublicKeyInfos of the chain. The fingerprint
- // from the leaf certificate will be the first element of the vector.
- std::vector<SHA1Fingerprint> public_key_hashes;
+ // If the certificate was successfully verified then this contains the
+ // hashes, in several hash algorithms, of the SubjectPublicKeyInfos of the
+ // chain.
+ HashValueVector public_key_hashes;
// is_issued_by_known_root is true if we recognise the root CA as a standard
// root. If it isn't then it's probably the case that this certificate was